@@ -17,7 +17,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.1.5';
+    $VERSION = '2.1.7';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -282,7 +282,7 @@ sub add_defaults {
         'default-scan-options'              => undef,
         'rotate facing'                     => 0,
         'rotate reverse'                    => 0,
-        'default filename'                  => '%Da %DY-%Dm-%Dd',
+        'default filename'                  => '%Da %DY-%Dm-%Dd.%De',
         'convert whitespace to underscores' => FALSE,
         'view files toggle'                 => TRUE,
         'threshold-before-ocr'              => FALSE,
