@@ -34,7 +34,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.1.6';
+    $VERSION = '2.1.7';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -690,14 +690,20 @@ sub resolution {
 
 sub matching_paper_sizes {
     my ( $self, $paper_sizes ) = @_;
+    my %matching;
     if ( not( defined $self->{height} and defined $self->{width} ) ) {
         my $image = $self->im_object;
         $self->{width}  = $image->Get('width');
         $self->{height} = $image->Get('height');
+        if ( not( defined $self->{height} and defined $self->{width} ) ) {
+            $logger->warn(
+"ImageMagick returns undef for image size - resolution cannot be guessed"
+            );
+            return \%matching;
+        }
     }
     my $ratio = $self->{height} / $self->{width};
     if ( $ratio < 1 ) { $ratio = 1 / $ratio }
-    my %matching;
     for ( keys %{$paper_sizes} ) {
         if ( $paper_sizes->{$_}{x} > 0
             and abs( $ratio - $paper_sizes->{$_}{y} / $paper_sizes->{$_}{x} ) <
@@ -721,7 +727,7 @@ sub im_object {
     my ($self) = @_;
     my $image  = Image::Magick->new;
     my $x      = $image->Read( $self->{filename} );
-    if ("$x") { $logger->warn("Error creating IM object - $x") }
+    if ("$x") { $logger->warn("Error creating IM object - $x"); croak $x }
     return $image;
 }
 
